@@ -1,5 +1,5 @@
 /* This is part of libio/iostream, providing -*- C++ -*- input/output.
-   Copyright (C) 1993, 1997 Free Software Foundation, Inc.
+   Copyright (C) 1993, 1997, 1998 Free Software Foundation, Inc.
 
    This file is part of the GNU IO Library.  This library is free
    software; you can redistribute it and/or modify it under the
@@ -333,11 +333,15 @@ READ_INT(bool)
 istream& istream::operator>>(long double& x)
 {
     if (ipfx0())
+      {
 #if _G_HAVE_LONG_DOUBLE_IO
 	scan("%Lg", &x);
 #else
-	scan("%lg", &x);
+	double y;
+	scan("%lg", &y);
+	x = y;
 #endif
+      }
     return *this;
 }
 
@@ -617,21 +621,24 @@ ostream& ostream::operator<<(double n)
 	// Do actual conversion.
 #if _G_HAVE_PRINTF_FP
 	{
-	  struct printf_info info = { prec: prec,
-				      width: width(0),
-				      spec: format_char,
-				      is_long_double: 0,
-				      is_short: 0,
-				      is_long: 0,
-				      alt: (flags() & ios::showpoint) != 0,
-				      space: 0,
-				      left: (flags() & ios::left) != 0,
-				      showsign: (flags() & ios::showpos) != 0,
-				      group: 0,
-				      pad: fill()
+	  struct printf_info info = { /* prec: */ prec,
+				      /* width: */ width(0),
+				      /* spec: */ format_char,
+				      /* is_long_double: */ 0,
+				      /* is_short: */ 0,
+				      /* is_long: */ 0,
+				      /* alt: */ (flags() & ios::showpoint) != 0,
+				      /* space: */ 0,
+				      /* left: */ (flags() & ios::left) != 0,
+				      /* showsign: */ (flags() & ios::showpos) != 0,
+				      /* group: */ 0,
 #if defined __GLIBC__ && __GLIBC__ >= 2
-				      , extra: 0
+				      /* extra: */ 0,
+#if __GLIBC_MINOR__ >= 1
+				      /* is_char: */ 0,
 #endif
+#endif
+				      /* pad: */ fill()
 	  };
 	  const void *ptr = (const void *) &n;
 	  if (__printf_fp (rdbuf(), &info, &ptr) < 0)
@@ -720,21 +727,24 @@ ostream& ostream::operator<<(long double n)
 
 #if _G_HAVE_PRINTF_FP
       // Do actual conversion.
-      struct printf_info info = { prec: prec,
-				  width: width(0),
-				  spec: format_char,
-				  is_long_double: 1,
-				  is_short: 0,
-				  is_long: 0,
-				  alt: (flags() & ios::showpoint) != 0,
-				  space: 0,
-				  left: (flags() & ios::left) != 0,
-				  showsign: (flags() & ios::showpos) != 0,
-				  group: 0,
-				  pad: fill()
+      struct printf_info info = { /* prec: */ prec,
+				  /* width: */ width(0),
+				  /* spec: */ format_char,
+			          /* is_long_double: */ 1,
+				  /* is_short: */ 0,
+				  /* is_long: */ 0,
+				  /* alt: */ (flags() & ios::showpoint) != 0,
+				  /* space: */ 0,
+				  /* left: */ (flags() & ios::left) != 0,
+				  /* showsign: */ (flags() & ios::showpos) != 0,
+				  /* group: */ 0,
 #if defined __GLIBC__ && __GLIBC__ >= 2
-				  , extra: 0
+				  /* extra: */ 0,
+#if __GLIBC_MINOR__ >= 1
+				  /* is_char: */ 0,
 #endif
+#endif
+				  /* pad: */ fill()
       };
 
       const void *ptr = (const void *) &n;
